@@ -19,6 +19,7 @@ from waterloo.types import (
     NameMatchesRelativeImportError,
     NameToStrategy_T,
     NotFoundNoPathError,
+    ReturnsSection,
     SourcePos,
     TypeAtom,
     TypeDef,
@@ -48,17 +49,23 @@ def get_type_comment(
         args = Types.ELLIPSIS
     if signature.return_type and signature.return_type.type_def:
         returns = signature.return_type.type_def.to_annotation(name_to_strategy)
+        if signature.return_type.name is ReturnsSection.YIELDS:
+            returns = f"Generator[{returns}, None, None]"
     else:
         # to avoid reaching this case, configure REQUIRE_RETURN_TYPE=True
         returns = Types.NONE
     return f"# type: ({args}) -> {returns}"
 
 
+# NOTE: `NotImplemented` and `Ellipsis` are still not handled properly
+# by mypy, see: https://github.com/python/mypy/issues/4791
+VALUE_TYPE_SINGLETONS = {"None", "NotImplemented", "Ellipsis,"}
+
 BUILTIN_TYPE_NAMES = {
     name
     for name in __builtins__.keys()  # type: ignore[attr-defined]
     if not name.startswith("__") and isinstance(eval(name), type)
-}
+} | VALUE_TYPE_SINGLETONS
 
 TYPING_TYPE_NAMES = {
     name
@@ -73,6 +80,9 @@ TYPING_TYPE_NAMES = {
     )
 }
 
+# NOTE: there is also a `types` module in stdlib containing things such as
+# `ModuleType`... for now Waterloo will need prefixed annotations for these
+
 
 def _is_builtin_type(name: str) -> bool:
     return name in BUILTIN_TYPE_NAMES
