@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import logging
 from collections import OrderedDict
 from collections.abc import Iterable as IterableABC
 from dataclasses import dataclass
@@ -205,7 +206,10 @@ class ReturnType:
 
     def type_names(self) -> Set[str]:
         if self.type_def:
-            return self.type_def.type_names()
+            names = self.type_def.type_names()
+            if self.name is ReturnsSection.YIELDS:
+                names.add("Generator")
+            return names
         return set()
 
 
@@ -351,10 +355,11 @@ class UnpathedTypePolicy(Enum):
 
 
 class LogLevel(Enum):
-    DEBUG = 0
-    INFO = 1
-    WARNING = 2
-    ERROR = 3
+    DEBUG = logging.DEBUG
+    INFO = logging.INFO
+    WARNING = logging.WARNING
+    ERROR = logging.ERROR
+    DISABLED = logging.ERROR + 100
 
 
 LOG_LEVEL_LABELS: Final = {
